# aiken_eng
This is a collection of tools used by Aiken Engineering Company.
## plotting
Sets the plot defaults for border, gridlines, tick marks, etc. to use with matplotlib.<br>
`plot(x, y, x_label, y_label, title)` - a simple one-line plot interface